==> duckdb_0.2.1.tar.gz: duckdb/src/duckdb/amalgamation-5.cpp <==
#line 0 "src/optimizer/pushdown/pushdown_mark_join.cpp"
#include "src/optimizer/pushdown/pushdown_mark_join.cpp"

#line 0 "src/optimizer/pushdown/pushdown_projection.cpp"
#include "src/optimizer/pushdown/pushdown_projection.cpp"

#line 0 "src/optimizer/pushdown/pushdown_set_operation.cpp"
#include "src/optimizer/pushdown/pushdown_set_operation.cpp"

#line 0 "src/optimizer/pushdown/pushdown_single_join.cpp"
#include "src/optimizer/pushdown/pushdown_single_join.cpp"

#line 0 "src/optimizer/regex_range_filter.cpp"
#include "src/optimizer/regex_range_filter.cpp"

#line 0 "src/optimizer/remove_unused_columns.cpp"
#include "src/optimizer/remove_unused_columns.cpp"

#line 0 "src/optimizer/rule/arithmetic_simplification.cpp"
#include "src/optimizer/rule/arithmetic_simplification.cpp"

#line 0 "src/optimizer/rule/case_simplification.cpp"
#include "src/optimizer/rule/case_simplification.cpp"

#line 0 "src/optimizer/rule/comparison_simplification.cpp"
#include "src/optimizer/rule/comparison_simplification.cpp"

#line 0 "src/optimizer/rule/conjunction_simplification.cpp"
#include "src/optimizer/rule/conjunction_simplification.cpp"

#line 0 "src/optimizer/rule/constant_folding.cpp"
#include "src/optimizer/rule/constant_folding.cpp"

#line 0 "src/optimizer/rule/date_part_simplification.cpp"
#include "src/optimizer/rule/date_part_simplification.cpp"

#line 0 "src/optimizer/rule/distributivity.cpp"
#include "src/optimizer/rule/distributivity.cpp"

#line 0 "src/optimizer/rule/empty_needle_removal.cpp"
#include "src/optimizer/rule/empty_needle_removal.cpp"

#line 0 "src/optimizer/rule/like_optimizations.cpp"
#include "src/optimizer/rule/like_optimizations.cpp"

#line 0 "src/optimizer/rule/move_constants.cpp"
#include "src/optimizer/rule/move_constants.cpp"

#line 0 "src/optimizer/topn_optimizer.cpp"
#include "src/optimizer/topn_optimizer.cpp"

#line 0 "src/parallel/executor.cpp"
#include "src/parallel/executor.cpp"

#line 0 "src/parallel/pipeline.cpp"
#include "src/parallel/pipeline.cpp"

#line 0 "src/parallel/task_scheduler.cpp"
#include "src/parallel/task_scheduler.cpp"

#line 0 "src/parallel/thread_context.cpp"
#include "src/parallel/thread_context.cpp"

#line 0 "src/parser/base_expression.cpp"
#include "src/parser/base_expression.cpp"

#line 0 "src/parser/column_definition.cpp"
#include "src/parser/column_definition.cpp"

#line 0 "src/parser/constraint.cpp"
#include "src/parser/constraint.cpp"

#line 0 "src/parser/constraints/check_constraint.cpp"
#include "src/parser/constraints/check_constraint.cpp"

#line 0 "src/parser/constraints/not_null_constraint.cpp"
#include "src/parser/constraints/not_null_constraint.cpp"

#line 0 "src/parser/constraints/unique_constraint.cpp"
#include "src/parser/constraints/unique_constraint.cpp"

#line 0 "src/parser/expression/case_expression.cpp"
#include "src/parser/expression/case_expression.cpp"

#line 0 "src/parser/expression/cast_expression.cpp"
#include "src/parser/expression/cast_expression.cpp"

#line 0 "src/parser/expression/collate_expression.cpp"
#include "src/parser/expression/collate_expression.cpp"

#line 0 "src/parser/expression/columnref_expression.cpp"
#include "src/parser/expression/columnref_expression.cpp"

#line 0 "src/parser/expression/comparison_expression.cpp"
#include "src/parser/expression/comparison_expression.cpp"

#line 0 "src/parser/expression/conjunction_expression.cpp"
#include "src/parser/expression/conjunction_expression.cpp"

#line 0 "src/parser/expression/constant_expression.cpp"
#include "src/parser/expression/constant_expression.cpp"

#line 0 "src/parser/expression/default_expression.cpp"
#include "src/parser/expression/default_expression.cpp"

#line 0 "src/parser/expression/function_expression.cpp"
#include "src/parser/expression/function_expression.cpp"

#line 0 "src/parser/expression/operator_expression.cpp"
#include "src/parser/expression/operator_expression.cpp"

#line 0 "src/parser/expression/parameter_expression.cpp"
#include "src/parser/expression/parameter_expression.cpp"

#line 0 "src/parser/expression/star_expression.cpp"
#include "src/parser/expression/star_expression.cpp"

#line 0 "src/parser/expression/subquery_expression.cpp"
#include "src/parser/expression/subquery_expression.cpp"

#line 0 "src/parser/expression/table_star_expression.cpp"
#include "src/parser/expression/table_star_expression.cpp"

#line 0 "src/parser/expression/window_expression.cpp"
#include "src/parser/expression/window_expression.cpp"

#line 0 "src/parser/expression_util.cpp"
#include "src/parser/expression_util.cpp"

#line 0 "src/parser/parsed_data/alter_table_info.cpp"
#include "src/parser/parsed_data/alter_table_info.cpp"

#line 0 "src/parser/parsed_expression.cpp"
#include "src/parser/parsed_expression.cpp"

#line 0 "src/parser/parsed_expression_iterator.cpp"
#include "src/parser/parsed_expression_iterator.cpp"

#line 0 "src/parser/parser.cpp"
#include "src/parser/parser.cpp"

#line 0 "src/parser/pragma_handler.cpp"
#include "src/parser/pragma_handler.cpp"

#line 0 "src/parser/query_node.cpp"
#include "src/parser/query_node.cpp"

#line 0 "src/parser/query_node/recursive_cte_node.cpp"
#include "src/parser/query_node/recursive_cte_node.cpp"

#line 0 "src/parser/query_node/select_node.cpp"
#include "src/parser/query_node/select_node.cpp"

#line 0 "src/parser/query_node/set_operation_node.cpp"
#include "src/parser/query_node/set_operation_node.cpp"

#line 0 "src/parser/result_modifier.cpp"
#include "src/parser/result_modifier.cpp"

#line 0 "src/parser/statement/select_statement.cpp"
#include "src/parser/statement/select_statement.cpp"

#line 0 "src/parser/tableref.cpp"
#include "src/parser/tableref.cpp"

#line 0 "src/parser/tableref/basetableref.cpp"
#include "src/parser/tableref/basetableref.cpp"

#line 0 "src/parser/tableref/crossproductref.cpp"
#include "src/parser/tableref/crossproductref.cpp"

#line 0 "src/parser/tableref/emptytableref.cpp"
#include "src/parser/tableref/emptytableref.cpp"

#line 0 "src/parser/tableref/expressionlistref.cpp"
#include "src/parser/tableref/expressionlistref.cpp"

#line 0 "src/parser/tableref/joinref.cpp"
#include "src/parser/tableref/joinref.cpp"

#line 0 "src/parser/tableref/subqueryref.cpp"
#include "src/parser/tableref/subqueryref.cpp"

#line 0 "src/parser/tableref/table_function.cpp"
#include "src/parser/tableref/table_function.cpp"

#line 0 "src/parser/transform/constraint/transform_constraint.cpp"
#include "src/parser/transform/constraint/transform_constraint.cpp"

#line 0 "src/parser/transform/expression/transform_bool_expr.cpp"
#include "src/parser/transform/expression/transform_bool_expr.cpp"

#line 0 "src/parser/transform/expression/transform_case.cpp"
#include "src/parser/transform/expression/transform_case.cpp"

#line 0 "src/parser/transform/expression/transform_cast.cpp"
#include "src/parser/transform/expression/transform_cast.cpp"

#line 0 "src/parser/transform/expression/transform_coalesce.cpp"
#include "src/parser/transform/expression/transform_coalesce.cpp"

#line 0 "src/parser/transform/expression/transform_columnref.cpp"
#include "src/parser/transform/expression/transform_columnref.cpp"

#line 0 "src/parser/transform/expression/transform_constant.cpp"
#include "src/parser/transform/expression/transform_constant.cpp"

#line 0 "src/parser/transform/expression/transform_expression.cpp"
#include "src/parser/transform/expression/transform_expression.cpp"

#line 0 "src/parser/transform/expression/transform_function.cpp"
#include "src/parser/transform/expression/transform_function.cpp"

#line 0 "src/parser/transform/expression/transform_is_null.cpp"
#include "src/parser/transform/expression/transform_is_null.cpp"

#line 0 "src/parser/transform/expression/transform_operator.cpp"
#include "src/parser/transform/expression/transform_operator.cpp"

#line 0 "src/parser/transform/expression/transform_param_ref.cpp"
#include "src/parser/transform/expression/transform_param_ref.cpp"

#line 0 "src/parser/transform/expression/transform_subquery.cpp"
#include "src/parser/transform/expression/transform_subquery.cpp"

==> duckdb_0.2.1-2.tar.gz: duckdb/src/duckdb/amalgamation-5.cpp <==
#include "src/optimizer/pushdown/pushdown_projection.cpp"

#include "src/optimizer/pushdown/pushdown_set_operation.cpp"

#include "src/optimizer/pushdown/pushdown_single_join.cpp"

#include "src/optimizer/regex_range_filter.cpp"

#include "src/optimizer/remove_unused_columns.cpp"

#include "src/optimizer/rule/arithmetic_simplification.cpp"

#include "src/optimizer/rule/case_simplification.cpp"

#include "src/optimizer/rule/comparison_simplification.cpp"

#include "src/optimizer/rule/conjunction_simplification.cpp"

#include "src/optimizer/rule/constant_folding.cpp"

#include "src/optimizer/rule/date_part_simplification.cpp"

#include "src/optimizer/rule/distributivity.cpp"

#include "src/optimizer/rule/empty_needle_removal.cpp"

#include "src/optimizer/rule/like_optimizations.cpp"

#include "src/optimizer/rule/move_constants.cpp"

#include "src/optimizer/topn_optimizer.cpp"

#include "src/parallel/executor.cpp"

#include "src/parallel/pipeline.cpp"

#include "src/parallel/task_scheduler.cpp"

#include "src/parallel/thread_context.cpp"

#include "src/parser/base_expression.cpp"

#include "src/parser/column_definition.cpp"

#include "src/parser/constraint.cpp"

#include "src/parser/constraints/check_constraint.cpp"

#include "src/parser/constraints/not_null_constraint.cpp"

#include "src/parser/constraints/unique_constraint.cpp"

#include "src/parser/expression/case_expression.cpp"

#include "src/parser/expression/cast_expression.cpp"

#include "src/parser/expression/collate_expression.cpp"

#include "src/parser/expression/columnref_expression.cpp"

#include "src/parser/expression/comparison_expression.cpp"

#include "src/parser/expression/conjunction_expression.cpp"

#include "src/parser/expression/constant_expression.cpp"

#include "src/parser/expression/default_expression.cpp"

#include "src/parser/expression/function_expression.cpp"

#include "src/parser/expression/operator_expression.cpp"

#include "src/parser/expression/parameter_expression.cpp"

#include "src/parser/expression/star_expression.cpp"

#include "src/parser/expression/subquery_expression.cpp"

#include "src/parser/expression/table_star_expression.cpp"

#include "src/parser/expression/window_expression.cpp"

#include "src/parser/expression_util.cpp"

#include "src/parser/parsed_data/alter_table_info.cpp"

#include "src/parser/parsed_expression.cpp"

#include "src/parser/parsed_expression_iterator.cpp"

#include "src/parser/parser.cpp"

#include "src/parser/query_node.cpp"

#include "src/parser/query_node/recursive_cte_node.cpp"

#include "src/parser/query_node/select_node.cpp"

#include "src/parser/query_node/set_operation_node.cpp"

#include "src/parser/result_modifier.cpp"

#include "src/parser/statement/select_statement.cpp"

#include "src/parser/tableref.cpp"

#include "src/parser/tableref/basetableref.cpp"

#include "src/parser/tableref/crossproductref.cpp"

#include "src/parser/tableref/emptytableref.cpp"

#include "src/parser/tableref/expressionlistref.cpp"

#include "src/parser/tableref/joinref.cpp"

#include "src/parser/tableref/subqueryref.cpp"

#include "src/parser/tableref/table_function.cpp"

#include "src/parser/transform/constraint/transform_constraint.cpp"

#include "src/parser/transform/expression/transform_bool_expr.cpp"

#include "src/parser/transform/expression/transform_case.cpp"

#include "src/parser/transform/expression/transform_cast.cpp"

#include "src/parser/transform/expression/transform_coalesce.cpp"

#include "src/parser/transform/expression/transform_columnref.cpp"

#include "src/parser/transform/expression/transform_constant.cpp"

#include "src/parser/transform/expression/transform_expression.cpp"

#include "src/parser/transform/expression/transform_function.cpp"

#include "src/parser/transform/expression/transform_is_null.cpp"

#include "src/parser/transform/expression/transform_operator.cpp"

#include "src/parser/transform/expression/transform_param_ref.cpp"

#include "src/parser/transform/expression/transform_subquery.cpp"

#include "src/parser/transform/helpers/nodetype_to_string.cpp"

#include "src/parser/transform/helpers/transform_alias.cpp"

#include "src/parser/transform/helpers/transform_cte.cpp"

#include "src/parser/transform/helpers/transform_groupby.cpp"
